@@ -151,9 +151,16 @@ class ContainerLauncher:
                 instance_type = container_input['instance_type']
                 ec2_instances = [{'instance_type': instance_type}]
             else:
-                ec2 = Ec2({
+                ec2_options = {
                     'region': self.__region
-                })
+                }
+                if self.__options is not None and self.__options.get('clients') is not None and self.__options[
+                    'clients'].get('amazon_ec2_best_instance_ec2_client') is not None:
+                    ec2_options['clients'] = {
+                        'ec2': self.__options['clients']['amazon_ec2_best_instance_ec2_client']
+                    }
+                print('ec2_options', ec2_options)
+                ec2 = Ec2(ec2_options)
                 self.logger.debug('Getting an optimal instance type')
                 get_optimal_instance_type_input = {
                     'cpu': container_input['cpu'],
@@ -971,7 +978,7 @@ class ContainerLauncher:
         task_role_name = task_role_arn.split('/')[-1] if task_role_arn is not None else self.__resources[
             'ecs_task_iam_role_name']
         task_execution_role_name = task_execution_role_arn.split('/')[-1] if task_execution_role_arn is not None else \
-        self.__resources['ecs_task_execution_iam_role_name']
+            self.__resources['ecs_task_execution_iam_role_name']
         name_suffix = self.__options['name_suffix']
         task_definition_name = f'{self.__name_prefix}-task-def-{name_suffix}'
 
